@@ -18,6 +18,7 @@
 
 class KALedMeter;
 class QLCDNumber;
+class KDialogBase;
 
 class KAstTopLevel : public KMainWindow
 {
@@ -31,20 +32,19 @@ private:
     void playSound( const char *snd );
     void readSoundMapping();
     void doStats();
+    bool queryExit();
     bool processKeyPress( QKeyEvent *event );
     bool processKeyRelease( QKeyEvent *event );
 
-
 protected:
     virtual bool eventFilter( QObject *object, QEvent *event );
     virtual void focusInEvent( QFocusEvent *event );
     virtual void focusOutEvent( QFocusEvent *event );
 
 private slots:
-    void readSettings(); // it is useful as a slot
+    void loadSettings();
     void slotNewGame();
     void slotGameOver();
-    void slotQuit();
 
     void slotShipKilled();
     void slotRockHit( int size );
@@ -72,20 +72,17 @@ private:
     QLCDNumber *shootLCD;
     KALedMeter *powerMeter;
 
-    bool   sound;
     QDict<QString> soundDict;
 
     // waiting for user to press Enter to launch a ship
     bool waitShip;
-    bool isPaused;
     bool gameOver;
 
     int shipsRemain;
     int score;
     int level;
-    bool showHiscores;
 
-    enum Action { Invalid, Launch, Thrust, RotateLeft, RotateRight, Shoot, 
+    enum Action { Invalid, Launch, Thrust, RotateLeft, RotateRight, Shoot,
                     Teleport, Brake, Shield };
 
     QMap<Action, KAction*> keycodes;
