@@ -131,14 +131,14 @@ bool KBVerticalStepStrategy::hasMoreShots()
 	else
 	{
 		// Parent Strategy
-		if((!m_destroying) && m_prevShots->count() > 0)
+		if((!m_destroying) && m_prevShots.count() > 0)
 		{
-			QPoint* pos = m_prevShots->last();
-			int state = m_battleField->ownState(pos->x(), pos->y());
+			QPoint pos = m_prevShots.last();
+			int state = m_battleField->ownState(pos.x(), pos.y());
 			if(state == KBattleField::HIT)
 			{
 				m_destroying = true;
-				m_destroyer->destroyShipAt(*pos);
+				m_destroyer->destroyShipAt(pos);
 			}
 		}
 		if(m_destroying)
@@ -208,7 +208,7 @@ bool KBVerticalStepStrategy::hasMoreShots()
 
 void KBVerticalStepStrategy::shotAt(const QPoint &pos)
 {
-	m_prevShots->append(new QPoint(pos));
+	m_prevShots.append(pos);
 	if(m_child != 0)
 		m_child->shotAt(pos);
 }
