@@ -328,7 +328,6 @@ bool Slope::collision(Ball *ball, long int /*id*/)
 	}
 
 	ball->setVelocity(vx, vy);
-
 	// check if the ball is at the center of a pit or mound
 	// or has otherwise stopped.
 	if (vx == 0 && vy ==0)
@@ -552,7 +551,7 @@ SlopeConfig::SlopeConfig(Slope *slope, QWidget *parent)
 	hlayout->addWidget(grade);
 	connect(grade, SIGNAL(valueChanged(double)), this, SLOT(gradeChanged(double)));
 
-	QCheckBox *stuck = new QCheckBox(i18n("Unmoveable"), this);
+	QCheckBox *stuck = new QCheckBox(i18n("Unmovable"), this);
 	QWhatsThis::add(stuck, i18n("Whether or not this slope can be moved by other objects, like floaters."));
 	stuck->setChecked(slope->isStuckOnGround());
 	layout->addWidget(stuck);
