@@ -1,6 +1,6 @@
 
-#ifndef __CMD_LINE_CHOP_H
-#define __CMD_LINE_CHOP_H
+#ifndef FC_SOLVE__CMD_LINE_CHOP_H
+#define FC_SOLVE__CMD_LINE_CHOP_H
 
 struct args_man_struct
 {
@@ -15,5 +15,5 @@ extern args_man_t * freecell_solver_args_man_alloc(void);
 extern void freecell_solver_args_man_free(args_man_t * manager);
 extern int freecell_solver_args_man_chop(args_man_t * manager, char * string);
 
-#endif /* #ifndef __CMD_LINE_CHOP_H */
+#endif /* #ifndef FC_SOLVE__CMD_LINE_CHOP_H */
 
