@@ -12,16 +12,15 @@ class KSBoard : public Board
 	void copy(const GenericTetris &);
 
 	void start(const GTInitData &);
-
     enum Constants { Width = 10, Nb_Stages = 6 };
-
- signals:
-    void removedLinesUpdated(uint nb, uint totalRemoved);
+    uint nbRemovedLines(uint i) const { return linesRemoved[i]; }
+    uint lastRemoved() const { return _lastRemoved; }
 
  private:
-    QMemArray<uint>   filled;
+    QMemArray<uint> filled;
     QMemArray<uint> linesRemoved;
 	uint            addRemoved;
+    uint _lastRemoved;
 
     struct StageData {
         uint todo, speed;
@@ -30,15 +29,16 @@ class KSBoard : public Board
     };
     static const StageData STAGE_DATA[Nb_Stages];
 
+    void init();
 	uint gift();
 	bool putGift(uint nb);
 	bool _putGift(uint nb);
 	bool needRemoving();
     void remove();
-    bool toBeRemoved(const Grid2D::Coord &) const;
-    bool toFall(const Grid2D::Coord &) const;
+    bool toBeRemoved(const KGrid2D::Coord &) const;
+    bool toFall(const KGrid2D::Coord &) const;
     void computeInfos();
-    void setGarbageBlock(const Grid2D::Coord &);
+    void setGarbageBlock(const KGrid2D::Coord &);
 
     const StageData &stageData() const { return STAGE_DATA[arcadeStage()]; }
     uint normalTime() const;
