@@ -3,12 +3,14 @@
 
 #include "kzoommainwindow.h"
 
+#include <kdemacros.h>
+
 class BaseInterface;
 class KToggleAction;
 class KKeyDialog;
 class KConfigDialog;
 
-class BaseMainWindow : public KZoomMainWindow
+class KDE_EXPORT BaseMainWindow : public KZoomMainWindow
 {
     Q_OBJECT
 public:
