@@ -5,6 +5,8 @@
 #include "base/field.h"
 #include "types.h"
 
+#include "lib/libksirtet_export.h"
+
 
 class ShowNextPiece;
 class GiftShower;
@@ -13,14 +15,12 @@ class KProgress;
 class KGameProgress;
 class KGameLCDClock;
 
-class Field : public MPSimpleBoard, public BaseField
+class LIBKSIRTET_EXPORT Field : public MPSimpleBoard, public BaseField
 {
  Q_OBJECT
  public:
     Field(QWidget *parent);
 
-    QSizePolicy sizePolicy() const;
-
  public slots:
     void moveLeft();
     void moveRight();
@@ -32,21 +32,19 @@ class Field : public MPSimpleBoard, public BaseField
     void moveLeftTotal();
     void moveRightTotal();
 
-    void settingsChanged();
+    virtual void settingsChanged();
 
- private slots:
+ protected slots:
     void scoreUpdatedSlot() { scoreUpdated(); }
-    void levelUpdated();
-    void removedUpdated();
+    virtual void levelUpdated();
+    virtual void removedUpdated();
 
  private:
     KGameLCDClock *showTime;
     ShowNextPiece *showNext;
-    KGameLCDList  *showLevel;
     KProgress     *toLevel;
-    QLabel        *labShowNext;
+    QLabel        *labShowNext, *levelLabel;
     KGameProgress *prevHeight, *nextHeight;
-    GiftShower    *giftReceived, *giftSent;
     Shadow        *shadow;
     KCanvasRootPixmap *_snRootPixmap;
     ClientPlayData _cpd;
