@@ -3,9 +3,9 @@
 
 #include "base/highscores.h"
 
-#include <kdemacros.h>
+#include "lib/libksirtet_export.h"
 
-class KDE_EXPORT CommonHighscores : public BaseHighscores
+class LIBKSIRTET_EXPORT CommonHighscores : public BaseHighscores
 {
  public:
     CommonHighscores();
